/*******************************************************************************
 * Copyright (c) 2013, Perforce Software
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 * 
 * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/
package com.perforce.search.controller;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.servlet.ModelAndView;

import com.perforce.search.configuration.Configuration;
import com.perforce.search.model.impl.ErrorModels;

@Controller
public class RootController {
    // private static final Logger log = Logger.getLogger(RootController.class);

    private Configuration config;

    public RootController(final Configuration config) {
	this.config = config;
    }

    @RequestMapping("/")
    public void home(final HttpServletResponse response,
	    final HttpServletRequest request) throws IOException {
	response.sendRedirect(response.encodeRedirectURL("/ui/search.html"));
    }

    @RequestMapping("/version")
    public ModelAndView getVersion(final HttpServletResponse response,
	    final HttpServletRequest request) {
	return ResponseBuilder.buildResponse("version", ErrorModels.Error_OK);
    }

    @RequestMapping("/api/configuration")
    public ModelAndView getConfig(final HttpServletResponse response,
	    final HttpServletRequest request) {
	Map<String, String> payload = new HashMap<String, String>();
	payload.put("commonsURL", config.getCommonsUrl());
	payload.put("swarmURL", config.getSwarmUrl());
	payload.put("p4webURL", config.getP4WebUrl());

	return ResponseBuilder.buildResponse(payload);
    }

    @RequestMapping("/notauthorized")
    public ModelAndView notAuthorized(final HttpServletResponse response,
	    final HttpServletRequest request) {
	return ResponseBuilder.buildResponse(ErrorModels.Error_NotAuthorized);
    }

    // requires authentication
    @RequestMapping("/api/userid")
    public ModelAndView getUserId(final HttpServletResponse response,
	    final HttpServletRequest request) {
	Map<String, String> payload = new HashMap<String, String>();
	payload.put("userId", request.getUserPrincipal().getName());
	return ResponseBuilder.buildResponse(payload);
    }
}
